# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ChewC',
                'doc_host': 'https://cjgo.github.io',
                'git_url': 'https://github.com/cjgo/ChewC',
                'lib_path': 'chewc'},
  'syms': { 'chewc.core': { 'chewc.core.Genome': ('core.html#genome', 'chewc/core.py'),
                            'chewc.core.Genome.__init__': ('core.html#genome.__init__', 'chewc/core.py'),
                            'chewc.core.Genome.create_genetic_map': ('core.html#genome.create_genetic_map', 'chewc/core.py'),
                            'chewc.core.Genome.shape': ('core.html#genome.shape', 'chewc/core.py'),
                            'chewc.core.Genome.to': ('core.html#genome.to', 'chewc/core.py'),
                            'chewc.core.Individual': ('core.html#individual', 'chewc/core.py'),
                            'chewc.core.Individual.__init__': ('core.html#individual.__init__', 'chewc/core.py'),
                            'chewc.core.Individual.create_random_individual': ( 'core.html#individual.create_random_individual',
                                                                                'chewc/core.py'),
                            'chewc.core.Individual.to': ('core.html#individual.to', 'chewc/core.py'),
                            'chewc.core.Population': ('core.html#population', 'chewc/core.py'),
                            'chewc.core.Population.__init__': ('core.html#population.__init__', 'chewc/core.py'),
                            'chewc.core.Population.add_individual': ('core.html#population.add_individual', 'chewc/core.py'),
                            'chewc.core.Population.calculate_allele_frequencies': ( 'core.html#population.calculate_allele_frequencies',
                                                                                    'chewc/core.py'),
                            'chewc.core.Population.calculate_genetic_diversity': ( 'core.html#population.calculate_genetic_diversity',
                                                                                   'chewc/core.py'),
                            'chewc.core.Population.create_random_founder_population': ( 'core.html#population.create_random_founder_population',
                                                                                        'chewc/core.py'),
                            'chewc.core.Population.get_dosages': ('core.html#population.get_dosages', 'chewc/core.py'),
                            'chewc.core.Population.get_genotypes': ('core.html#population.get_genotypes', 'chewc/core.py'),
                            'chewc.core.Population.size': ('core.html#population.size', 'chewc/core.py'),
                            'chewc.core.Population.to': ('core.html#population.to', 'chewc/core.py'),
                            'chewc.core.PopulationDataset': ('core.html#populationdataset', 'chewc/core.py'),
                            'chewc.core.PopulationDataset.__getitem__': ('core.html#populationdataset.__getitem__', 'chewc/core.py'),
                            'chewc.core.PopulationDataset.__init__': ('core.html#populationdataset.__init__', 'chewc/core.py'),
                            'chewc.core.PopulationDataset.__len__': ('core.html#populationdataset.__len__', 'chewc/core.py'),
                            'chewc.core.create_population_dataloader': ('core.html#create_population_dataloader', 'chewc/core.py')},
            'chewc.crossing': { 'chewc.crossing.make_DH': ('crossing.html#make_dh', 'chewc/crossing.py'),
                                'chewc.crossing.make_cross': ('crossing.html#make_cross', 'chewc/crossing.py'),
                                'chewc.crossing.truncate_select': ('crossing.html#truncate_select', 'chewc/crossing.py')},
            'chewc.meiosis': { 'chewc.meiosis.gamma_interference_model': ('meiosis.html#gamma_interference_model', 'chewc/meiosis.py'),
                               'chewc.meiosis.simulate_gametes': ('meiosis.html#simulate_gametes', 'chewc/meiosis.py'),
                               'chewc.meiosis.simulate_meiosis': ('meiosis.html#simulate_meiosis', 'chewc/meiosis.py')},
            'chewc.trait': {'chewc.trait.select_qtl_loci': ('trait.html#select_qtl_loci', 'chewc/trait.py')}}}
